@@ -30,6 +30,13 @@ class Message:
         """ID сообщения."""
         if self.data.get("id"):
             return int(self.data.get("id"))
+    @property
+    def is_admin(self):
+        """Является ли человек администратором в чате."""
+        if not self.data.get('is_admin'):
+            return False
+        else:
+            return bool(self.data.get('is_admin'))
     
 class Post:
     def __init__(self, post: dict[str, str]):
@@ -105,8 +112,8 @@ class Bot:
                 return False
         else:
             return True
-    def send_media(self, media: Any) -> bool:
-        """Отправка медиа в чат любого типа. Видео, фото, файлы любых разрешений до 500 МБ.\nmedia: base64/bytes/buffer (к примеру, `open()`)"""
+    def send_media(self, media: Any) -> str:
+        """Отправка медиа в чат любого типа. Видео, фото, файлы любых разрешений до 500 МБ.\nmedia: base64/bytes/buffer (к примеру, `open()`)\nВозвращает ссылку на отправленное медиа."""
         r = requests.post("https://florestmsgs-florestdev4185.amvera.io/api/bot/send_media", headers={"X-Bot-Token":self.token}, files={"file":media}, proxies=self.proxies)
         if r.status_code != 200:
             if self.raise_on_status_code:
@@ -114,7 +121,7 @@ class Bot:
             else:
                 return False
         else:
-            return True
+            return r.json().get("url")
     def get_blogs(self) -> list[Post]:
         """Список постов с `/blogs`."""
         r = requests.get("https://florestmsgs-florestdev4185.amvera.io/api/bot/get_blogs", headers={"X-Bot-Token":self.token}, proxies=self.proxies)
@@ -212,8 +219,8 @@ class AsyncBot:
             return False
 
 
-    async def send_media(self, media: Any) -> bool:
-        """Асинхронная отправка медиа в чат любого типа."""
+    async def send_media(self, media: Any) -> str:
+        """Асинхронная отправка медиа в чат любого типа.\nВозвращает ссылку на отправленное медиа."""
         url = f"https://florestmsgs-florestdev4185.amvera.io/api/bot/send_media"
         headers = {"X-Bot-Token": self.token}
 
@@ -221,7 +228,7 @@ class AsyncBot:
         try:
             async with aiohttp.ClientSession() as session:
                  data = aiohttp.FormData()
-                 data.add_field('file', media, filename='filename') # Добавьте имя файла, если знаете
+                 data.add_field('file', media)
                  async with session.post(url, headers=headers, data=data, proxy=self.proxies) as r:
                     if r.status != 200:
                         if self.raise_on_status_code:
@@ -229,7 +236,8 @@ class AsyncBot:
                         else:
                             return False
                     else:
-                        return True
+                        j = await r.json()
+                        return j.get("url")
         except aiohttp.ClientError as e:
             print(f"Ошибка клиента aiohttp: {e}")
             return False
